@@ -1,6 +1,6 @@
 
 
-fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.prop = 0.1,border = NULL, label = TRUE, lab.opt = list(), add = FALSE, maxv = NULL, tile.col = hsv(0.1,0.1,0.1,alpha=0.6), bg.col = "lightgrey",  ...  ){
+fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.prop = 0.1,border = NULL, label = TRUE, lab.opt = list(), add = FALSE, maxv = NULL, tile.col = hsv(0.1,0.1,0.1,alpha=0.6), bg.col = ifelse(add,NA,"lightgrey"), tile.border = NA, vp = NULL,  ...  ){
 	#tab <- t(tab)
 	dm <- dim(tab)
 	if(is.null(maxv)){
@@ -8,6 +8,12 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 	}
 	
 	nd <- length(dm)
+	
+	# expand gap.prop
+	tmp <- rep(tail(gap.prop,1),nd)
+	tmp[seq_along(gap.prop)] <- gap.prop
+	gap.prop <- tmp
+	
 	#if(add){
 	#	bg.col = NA
 	#}
@@ -34,14 +40,18 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
     if("lab.cex" %in% names(lab.opt)){
         lab.cex <- lab.opt$lab.cex
     }else{
-        lab.cex = 1.2
+        lab.cex <- 1.2
     }
     if("rot" %in% names(lab.opt)){
         rot <- lab.opt$rot
     }else{
-        rot = 65
+        rot <- 65
+    }
+     if("lwd" %in% names(lab.opt)){
+        tile.lwd <- lab.opt$lwd
+    }else{
+        tile.lwd <- 1
     }
-    
 	data <- as.data.frame(as.table(tab))
 	
 	
@@ -88,10 +98,35 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 	
 	wph <- dm[2]/dm[1]
 #dev.new( width = 1000*(1-gap.prop)*wph + gap.prop*1000, height = 1000 )
-	if(!add){
-		#dev.new()
-		grid.newpage()
+
+
+	if(is.null(vp)){
+		if(!add){
+			grid.newpage()
+		}
+		vp <- viewport()
 	}
+
+
+	#if(!is.null(vp)){
+			if(!inherits(vp,"viewport")){
+				#stopifnot(length(vp)>1)
+				if(length(vp) < 2){
+					stop("Wrong viewport specification.")
+				}
+				if(is.null(current.viewport()$layout)){
+					print("No layout specified. Try:")
+					print("mat.layout <- grid.layout(nrow, ncol); grid.newpage(); vp.mat <- viewport(layout = mat.layout); pushViewport(vp.mat)")
+				}
+				
+				vp <- viewport(layout.pos.row = vp[1], layout.pos.col = vp[2])
+				
+			}
+			pushViewport(vp)
+		#}else{
+			
+		#}
+	
 	vp0 = viewport(x = border[1] + (1-border[1]-border[2])/2 , y = border[3] + (1-border[3]-border[4])/2, width = 1-border[1]-border[2], height = 1-border[3]-border[4],name="base")
 	if(length(dm)==2){
 		
@@ -99,14 +134,17 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 		#if(shape %in% c("r","c")){
 			nn <- length(tab)
 			tile.col <- rep(tile.col, ceiling(nn/length(tile.col)))[1:nn]
-			dim(tile.col) <- dim(tab)
+			tile.border <- rep(tile.border, ceiling(nn/length(tile.border)))[1:nn]
+			dim(tile.col) <- dim(tile.border) <- dim(tab)
+			
 			tile.col = tile.col[nrow(tile.col):1,]
+			tile.border = tile.border[nrow(tile.border):1,]
 		#}
 		
 		
 		pushViewport(vp0)
 		if(!add){
-		#grid.newpage()
+			#grid.newpage()
 			grid.rect(gp = gpar(fill=rgb(0,0,0,alpha=0.05),col=NA))
 		}
 # handle the last 2 dimensions
@@ -122,7 +160,7 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 				dim(tab) <- c( prod(dim(tab)), 1)	
 			}
 		}
-		gridfluc(tab,dir,just,shape,gap.prop, maxv=maxv, bg = bg.col, col = tile.col)
+		gridfluc(tab,dir,just,shape,gap.prop, maxv=maxv, bg = bg.col, col = tile.col,border = tile.border, lwd = tile.lwd)
 		popViewport()
 		
 # add labels
@@ -133,14 +171,14 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 			
 			m <- dm[2]
 			xc <- seq(0.5,m-0.5) / m
-			xc <- xc - gap.prop/(m-1)/2
-			xc <- xc/(1 - gap.prop/(m-1))
+			xc <- xc - gap.prop[2]/(m-1)/2
+			xc <- xc/(1 - gap.prop[2]/(m-1))
 			
 			
 			n <- dm[1]
 			yc <- seq(0.5,n-0.5) / n
-			yc <- yc - gap.prop/(n-1)/2
-			yc <- yc/(1 - gap.prop/(n-1))
+			yc <- yc - gap.prop[1]/(n-1)/2
+			yc <- yc/(1 - gap.prop[1]/(n-1))
 			
 			
 			vpR <- viewport(x = border[1]/2, y = border[3] + (1-border[3] -border[4])/2, width = border[1], height = 1-border[3]-border[4],name="rowlabs")
@@ -176,6 +214,16 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 			
 			popViewport()
 		}
+		
+			#if(!add | !is.null(vp)){
+			#	try( upViewport(), silent = TRUE )
+			#}
+		
+			#if(!is.null(vp)){
+			#	try( upViewport(), silent = TRUE )
+			#}
+		upViewport()
+		
 		return(vp0)
 	}else{
 		e1 <- new.env()
@@ -199,16 +247,13 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 #pushViewport(ss)
 			   seekViewport(y)
 			   
-#			if(hsp[1] & hsp[2]) dim(x) <- c(1, prod(dim(x)))
-#			if(!hsp[1] & !hsp[2]) dim(x) <- c( prod(dim(x)), 1)
-#			if(hsp[1] & !hsp[2]) x <- as.table(t(x))
 			   if(hsp[length(hsp)-1] & hsp[length(hsp)]) dim(x) <- c(1, prod(dim(x)))
 			   if(!hsp[length(hsp)-1] & !hsp[length(hsp)]) dim(x) <- c( prod(dim(x)), 1)
 			   if(hsp[length(hsp)-1] & !hsp[length(hsp)]) x <- as.table(t(x))
 			   
 #TODO: do something similar for the labels
 			   
-			   gridfluc(x,dir,just,shape,gp, maxv=maxv, bg = bg.col, col = tile.col)
+			   gridfluc(x,dir,just,shape,gp, maxv=maxv, bg = bg.col, col = tile.col, border = tile.border, lwd = tile.lwd)
 			   }, x = e1$tablist, y = e1$namlist, hs = e1$hslist, gp = e1$gplist)	
 		
 		upViewport()
@@ -242,6 +287,8 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 		gaps <- 0
 		blocksize <- 1
 		
+		row.gap.prop <- gap.prop[!hsp]
+		
 		for( i in 1:ny ){
 # viewport for the label column
 			currvp <- viewport( x = 1/ny/2+ (i-1)/ny, y = 0.5, width = 1/ny, height = 1)
@@ -251,34 +298,39 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
             
 			nl <- length(rlabs)
 			
+			
 # the gaps for the new dimension
-			newgaps <- c(0:(nlvl[i]-1)) * blocksize * gap.prop / (nlvl[i]-1)
+			newgaps <- c(0:(nlvl[i]-1)) * blocksize * row.gap.prop[i] / (nlvl[i]-1)
 			newgaps <- rep(newgaps, rpt[i])
 			
 			gaps <- rep(gaps, each = nlvl[i])
 			
 			x <- 0.5
 			if( i == 1 ){
-				y <- seq(1/nl/2,1-1/nl/2,1/nl)*((1-gap.prop)^i) + newgaps 
+				y <- seq(1/nl/2,1-1/nl/2,1/nl)*prod(1-row.gap.prop[1:i]) + newgaps  #seq*((1-gap.prop)^i)
 			}else{
 # the old coordinates +- the new gaps and cellwidths
-				y <- rep(y,each = nlvl[i]) + newgaps - max(newgaps)/2 + (1-gap.prop)*blocksize * rep(seq(1/nlvl[i]/2,1-1/nlvl[i]/2,1/nlvl[i])-0.5, rpt[i])
+				y <- rep(y,each = nlvl[i]) + newgaps - max(newgaps)/2 + (1-row.gap.prop[i])*blocksize * rep(seq(1/nlvl[i]/2,1-1/nlvl[i]/2,1/nlvl[i])-0.5, rpt[i])
 			}
 			
 			grid.text(rlabs, x = x, y = y , rot = rot[1], gp = gpar(cex=lab.cex[1]))
 #grid.points( x = rep(x,length(y)), y = y , gp = gpar(col="red"))
 			popViewport()
 			
-			blocksize <- blocksize * (1-gap.prop) / nlvl[i]
+			blocksize <- blocksize * (1-row.gap.prop[i]) / nlvl[i]
 		}
 		popViewport()
 		
-		vp2 <- viewport(x = border[1] + (1-border[1]-border[2])/2, y = 1 - border[4]/2, width = 1-border[1]-border[2], height = border[4],name="xlab")
-		pushViewport(vp2)
+
 #grid.rect(0.5,0.5,1,1,gp=gpar(fill=rgb(0,0,0,alpha=0.1)))
 		} # any ind
+		
 		ind <- label & hsp
 		if(any(ind)){
+			
+		vp2 <- viewport(x = border[1] + (1-border[1]-border[2])/2, y = 1 - border[4]/2, width = 1-border[1]-border[2], height = border[4],name="xlab")
+		pushViewport(vp2)
+			
 		ind <- which(ind)
 		
 		
@@ -287,6 +339,7 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 		nlvl <- dim(tab)[ind]
 		gaps <- 0
 		blocksize <- 1
+		col.gap.prop <- gap.prop[hsp]
 		
 		for( i in 1:nx ){
 # viewport for the label column
@@ -299,29 +352,40 @@ fluctile <- function(tab, dir = "b", just = "c", hsplit = FALSE,shape ="r", gap.
 			nl <- length(clabs)
 			
 			
-			newgaps <- c(0:(nlvl[i]-1)) * blocksize * gap.prop / (nlvl[i]-1)
+			newgaps <- c(0:(nlvl[i]-1)) * blocksize * col.gap.prop[i] / (nlvl[i]-1)
 			newgaps <- rep(newgaps, rpt[i]) 
 			
 #cat("labeling variable", names(data)[ind[i]], " with nlvl = ", nlvl[i], " and levels = ", labs," and rpt = ", rpt[i]) 
 			
 			y <- 0.5
 			if( i == 1 ){
-				x <- seq(1/nl/2,1-1/nl/2,1/nl)*((1-gap.prop)^i) + newgaps 
+				x <- seq(1/nl/2,1-1/nl/2,1/nl)*prod(1-col.gap.prop[1:i]) + newgaps # seq*((1-gap.prop)^i)
 			}else{
-				x <- rep(x,each = nlvl[i]) + newgaps - max(newgaps)/2 + (1-gap.prop)*blocksize * rep(seq(1/nlvl[i]/2,1-1/nlvl[i]/2,1/nlvl[i])-0.5, rpt[i])
+				x <- rep(x,each = nlvl[i]) + newgaps - max(newgaps)/2 + (1-col.gap.prop[i])*blocksize * rep(seq(1/nlvl[i]/2,1-1/nlvl[i]/2,1/nlvl[i])-0.5, rpt[i])
 			}
 #cat( "lab.x = ",x)
 			grid.text(clabs, x = x, y = y , rot = 90-rot[2], gp = gpar(cex=lab.cex[2]))
 #grid.points( x = x, y = rep(y,length(x)) , gp = gpar(col="red"))
 			popViewport()
 			
-			blocksize <- blocksize * (1-gap.prop) / nlvl[i]
+			blocksize <- blocksize * (1-col.gap.prop[i]) / nlvl[i]
 		}
-}# and ind
+		popViewport()
+}# any ind
 #
 # -------------------------------------------- LABELING  -------------------------------------------- #
 #######################################################################################################	
-		try(popViewport(),silent = TRUE)
+		#try(popViewport(),silent = TRUE)
+		
+		#if(!add){
+		#	try( upViewport(), silent = TRUE )
+		#}
+		
+		#if(!is.null(vp)){
+		#	try( upViewport(), silent = TRUE )
+		#}
+		upViewport()
+		
 		return(invisible(ss))
 	}
 }	
@@ -337,18 +401,14 @@ flucplot <- function(tab, gap.prop, hsplit, env, ...){
 	
 	dm <- dim(tab)
 	
-#	if(length(hsplit) == 1){
-#		hsplit = !hsplit	
-#	}else{
-		hsplit = hsplit[-1]	#hsplit[-length(hsplit)]#	
-#	}
+
 	
 #print(env$k)
 #print(env$vpn[env$k])
-#print(dm)
 	
 	if(length(dm) == 2){
 		
+		
 		env$k2 <- env$k2+1
 		k2 <- env$k2
 		env$tablist[[k2]] <- tab
@@ -357,6 +417,8 @@ flucplot <- function(tab, gap.prop, hsplit, env, ...){
 		env$gplist[[k2]] <- gap.prop
 		env$k <- env$k+1
 	}else{
+		hsplit <- hsplit[-1]		
+		gap.prop <- gap.prop[-1]
 		env$k <- env$k+1
 		apply(tab,1,function(z){
 			  flucplot(z,gap.prop, hsplit, env)
@@ -373,13 +435,13 @@ fluctree <- function(dims,parent, hsplit, gap.prop, env, ...){
 	
 	
 	if(hsplit[1]){
-		w <- rep((1-gap.prop)/nv,nv)
-		x <-  w/2 + 0:(nv-1)*(w + gap.prop/(nv-1)) 
+		w <- rep((1-gap.prop[1])/nv,nv)
+		x <-  w/2 + 0:(nv-1)*(w + gap.prop[1]/(nv-1)) 
 		h <- rep(1,nv)
 		y <- rep(0.5,nv)
 	}else{
-		h <- rep((1-gap.prop)/nv,nv)
-		y <- h/2 + 0:(nv-1)*(h + gap.prop/(nv-1))
+		h <- rep((1-gap.prop[1])/nv,nv)
+		y <- h/2 + 0:(nv-1)*(h + gap.prop[1]/(nv-1))
 		w <- rep(1,nv)
 		x <- rep(0.5,nv)
 	}
@@ -388,7 +450,7 @@ fluctree <- function(dims,parent, hsplit, gap.prop, env, ...){
 #}else{
 		hsplit <- hsplit[-1]	#hsplit[-length(hsplit)]#	
 #}
-	
+	  gap.prop <- gap.prop[-1]
 	
 	if(length(dims) > 2){
 		children <- vpList()
@@ -412,7 +474,9 @@ fluctree <- function(dims,parent, hsplit, gap.prop, env, ...){
 	
 }
 
-gridfluc <- function(tab,dir = "both", just = "centre", shape = "r", gap.prop = 0.1, maxv = NULL,vp = NULL, col = NULL, bg = NULL, border = NA,...){
+gridfluc <- function(tab,dir = "both", just = "centre", shape = "r", gap.prop = 0.1, maxv = NULL,vp = NULL, col = NULL, bg = NULL, border = NA, lwd = 1, ...){
+	
+	gap.prop <- rep(gap.prop,2)
 	
 	if(shape != "r" ){
 		just <- "centre"
@@ -429,24 +493,24 @@ gridfluc <- function(tab,dir = "both", just = "centre", shape = "r", gap.prop =
 	
 	n <- nrow(tab)
 	m <- ncol(tab)
-	w <- (1-gap.prop)/m
-	h <- (1-gap.prop)/n
+	w <- (1-gap.prop[2])/m
+	h <- (1-gap.prop[1])/n
 #centered x- and y-coords:
 	x <-  w/2  
 	y <- h/2 
 
 	if(n > 1){
-		y <- y + 0:(n-1)*(h+gap.prop/(n-1))	
+		y <- y + 0:(n-1)*(h+gap.prop[1]/(n-1))	
 	} 
 	if(m > 1){
-		x <- x + 0:(m-1)*(w+gap.prop/(m-1))
+		x <- x + 0:(m-1)*(w+gap.prop[2]/(m-1))
 	}  
 	if(is.null(maxv)){
 		maxv <- max(tab)	
 	}
 	
 	
-	draw2( h, w,  t(replicate(n,x)) , replicate(m,y), border = NA,bg=bg,vp=vp, just = "centre")
+	draw2( h, w,  t(replicate(n,x)) , replicate(m,y), border = NA,bg=bg, lwd = lwd, vp=vp, just = "centre")
 	
     if("right" %in% just){
         x <- x+w/2
@@ -483,11 +547,11 @@ if(dir == "n"){
     wt[tab > 0] <- w
 }
 	if(shape == "r"){
-		draw2(ht, wt,  t(replicate(n,x)), replicate(m,y), border = NA,bg=col, vp=vp, just = just)
+		draw2(ht, wt,  t(replicate(n,x)), replicate(m,y), border = border,bg=col, lwd = lwd, vp=vp, just = just)
 	}
 	
 	if(shape == "c"){
-		draw3(R = ht/2* (min(n,m)/max(m,n)), t(replicate(n,x)), replicate(m,y), border = NA,bg=col, vp=vp, just = just)
+		draw3(R = ht/2* (min(n,m)/max(m,n)), t(replicate(n,x)), replicate(m,y), border = border,bg=col, lwd = lwd, vp=vp, just = just)
 	}
 	if(shape %in% c("o", "d")){
 		if(shape == "o"){
@@ -518,7 +582,7 @@ if(dir == "n"){
 		idv <- rep(1:(m*n),each=ncr)
 		for(cc in uc){
 			ii <- which(colv == cc)
-			grid.polygon(x2[ii], y2[ii] , gp = gpar(col = border, fill = cc, alpha = 1), 
+			grid.polygon(x2[ii], y2[ii] , gp = gpar(col = border, fill = cc, alpha = 1,lwd = lwd), 
 				id = idv[ii])
 		}
 		
@@ -528,23 +592,35 @@ if(dir == "n"){
 }
 
 
-draw2 <- function (H, W, X, Y, alpha = 1, border = "black", bg = "white", 
+draw2 <- function (H, W, X, Y, alpha = 1, border = "black", bg = "white", lwd = 1, 
 vp = NULL, just = "centre") 
 {
+	if(!is.null(dim(border))){
+		border[which(H*W == 0)] <- NA
+	}
+	if(!is.null(dim(bg))){
+		bg[which(H*W == 0)] <- NA
+	}
 grid.rect(x = unit(X, "npc"), y = unit(Y, "npc"), width = unit(W, 
 "npc"), height = unit(H, "npc"), just = just, default.units = "npc", 
-name = NULL, gp = gpar(col = border, fill = bg, alpha = alpha), 
+name = NULL, gp = gpar(col = border, fill = bg, alpha = alpha, lwd = lwd), 
 draw = TRUE, vp = vp)
 }
 
 
 
-draw3 <- function (R, X, Y, alpha = 1, border = "black", bg = "white", 
+draw3 <- function (R, X, Y, alpha = 1, border = "black", bg = "white", lwd = 1,
 vp = NULL, just = "centre") 
 {
+	if(!is.null(dim(border))){
+		border[which(R == 0)] <- NA
+	}
+	if(!is.null(dim(bg))){
+		bg[which(R == 0)] <- NA
+	}
 grid.circle(x = unit(X, "npc"), y = unit(Y, "npc"), r = unit(R, 
 "npc"), default.units = "npc", 
-name = NULL, gp = gpar(col = border, fill = bg, alpha = alpha), 
+name = NULL, gp = gpar(col = border, fill = bg, alpha = alpha,lwd = lwd), 
 draw = TRUE, vp = vp)
 }
 
@@ -591,7 +667,7 @@ addrect = function( vp ,breaks, col = "red", lwd = 2, lty = 1, gap.prop = 0, rev
 
 
 cfluctile <- function(x, tau0 = NULL, method="Kendall", nsplit = NULL, maxsplit = NULL,  trafo = I, gap.prop = 0.2, 
-floor = 0, rev.y = FALSE, add = FALSE, shape = "r", just = "c", dir = "b", plot = TRUE ,rect.opt = list(), border = NULL, label = TRUE, lab.opt = list(), tile.col = hsv(0.1,0.1,0.1,alpha=0.6), bg.col = "lightgrey", ...){
+floor = 0, rev.y = FALSE, add = FALSE, shape = "r", just = "c", dir = "b", plot = TRUE ,rect.opt = list(), border = NULL, label = TRUE, lab.opt = list(), tile.col = hsv(0.1,0.1,0.1,alpha=0.6), tile.border = NA, bg.col = "lightgrey", ...){
 	
 	stopifnot(inherits(x,"table") | inherits(x,"matrix") )
 	stopifnot( length(dim(x)) == 2 )
@@ -640,7 +716,9 @@ floor = 0, rev.y = FALSE, add = FALSE, shape = "r", just = "c", dir = "b", plot
 	if( method %in% c("R","r","res","resid","residual",5) ){
 		method <- as.integer(5)	
 	}
-	
+	if( method %in% c("minres","mr","min.res",6) ){
+		method <- as.integer(6)	
+	}
 	ret.int <- ( storage.mode(x) == "integer" )
 	storage.mode(x) <- "numeric"
 	
@@ -680,6 +758,10 @@ floor = 0, rev.y = FALSE, add = FALSE, shape = "r", just = "c", dir = "b", plot
 			#ix <- itab(x)
 			tau0 <- 0.9 #<- 1 - exp(min( (x-ix)/sqrt(ix)  ))
 		}
+		if(method == 6){
+			#ix <- itab(x)
+			tau0 <- sum( abs(x - itab(x))/sqrt(itab(x)) )/sum(x)/2
+		}
 	}
 	
 	if( floor > 0 ){
@@ -771,9 +853,9 @@ floor = 0, rev.y = FALSE, add = FALSE, shape = "r", just = "c", dir = "b", plot
 	if(plot){
 		class(x) <- "matrix"
 	if(!add){
-		bs <- fluctile(trafo(x), gap.prop=gap.prop, shape = shape, just = just, dir = dir, tile.col = tile.col, bg.col = bg.col, label = label, lab.opt = lab.opt, border = border)
+		bs <- fluctile(trafo(x), gap.prop=gap.prop, shape = shape, just = just, dir = dir, tile.col = tile.col, tile.border = tile.border, bg.col = bg.col, label = label, lab.opt = lab.opt, border = border)
 	}else{
-		bs <- fluctile(trafo(x), gap.prop=gap.prop, bg.col=rgb(0,0,0,alpha=0),tile.col = rgb(0,0,0,alpha=0), add = TRUE, shape = shape, just = just, dir = dir, label = label, lab.opt = lab.opt, border = border)	
+		bs <- fluctile(trafo(x), gap.prop=gap.prop, bg.col=rgb(0,0,0,alpha=0),tile.col = rgb(0,0,0,alpha=0),tile.border = tile.border, add = TRUE, shape = shape, just = just, dir = dir, label = label, lab.opt = lab.opt, border = border)	
 	}
 	addrect(bs, breaks, col, gap.prop, rev.y = !rev.y, lwd = lwd, lty = lty, fill = fill)
 	}
@@ -789,164 +871,202 @@ floor = 0, rev.y = FALSE, add = FALSE, shape = "r", just = "c", dir = "b", plot
 
 
 
-fluctile3d = function(x, shape = "cube", col = "darkgrey", col.array = NULL, alpha = 0.8, add = FALSE, lab = TRUE, ...){
-	if(!"rgl" %in% .packages(all.available = TRUE)){
-		cat("Please install the package 'rgl' to run this function")
-		return(invisible(TRUE))
-	}
+# fluctile3d = function(x, shape = "cube", col = "darkgrey", col.array = NULL, alpha = 0.8, add = FALSE, lab = TRUE, ...){
+	# if(!"rgl" %in% .packages(all.available = TRUE)){
+		# cat("Please install the package 'rgl' to run this function")
+		# return(invisible(TRUE))
+	# }
 	
-	check <- tryCatch(require(rgl), error = function(e) FALSE)
-	if(!check){ 
-		cat("Problems with package 'rgl' occured...")
-		return(invisible(TRUE))
-	}
-	if(shape %in% c("o","oct","octahedron")){
-        shape <- "octagon"
-	}
-    if(!is.data.frame(x)){
-		x2 <- subtable(as.data.frame(as.table(x)),1:3)	
-		dim <- dim(x)
-	}else{
-		x2 <- subtable(x,1:3)
-		dim <- sapply(x,nlevels)[1:3]	
-	}
-	maxfreq <- max(x2$Freq)
-	lvls <- lapply(x2, levels)
-	x2 <- sapply(x2, as.integer)
+	# check <- tryCatch(require(rgl), error = function(e) FALSE)
+	# if(!check){ 
+		# cat("Problems with package 'rgl' occured...")
+		# return(invisible(TRUE))
+	# }
+	# if(shape %in% c("o","oct","octahedron")){
+        # shape <- "octagon"
+	# }
+    # if(!is.data.frame(x)){
+		# x2 <- subtable(as.data.frame(as.table(x)),1:3)	
+		# dim <- dim(x)
+	# }else{
+		# x2 <- subtable(x,1:3)
+		# dim <- sapply(x,nlevels)[1:3]	
+	# }
+	# maxfreq <- max(x2$Freq)
+	# lvls <- lapply(x2, levels)
+	# x2 <- sapply(x2, as.integer)
 	
-	if(is.null(col.array)){
-		col.array <- array(col,dim=dim)	
-	}
+	# if(is.null(col.array)){
+		# col.array <- array(col,dim=dim)	
+	# }
 	
 	
-	#MX <- identityMatrix()
-	MX <- matrix(0,ncol=4,nrow=4)
-	diag(MX) <- 1
-	if(!add){
-	open3d()
-#	lines3d(x = c(0.5,dim[1]+0.5), y = c(0.5,0.5), z =  c(0.5,0.5))
-#	lines3d(x = c(0.5,0.5), y = c(0.5,dim[2]+0.5), z =  c(0.5,0.5))
-#	lines3d(x = c(0.5,0.5), y = c(0.5,0.5), z =  c(0.5,dim[3]+0.5))
-#	lines3d(x = c(dim[1]+0.5,0.5), y = c(dim[2]+0.5,dim[2]+0.5), z =  c(dim[3]+0.5,dim[3]+0.5))
-#	lines3d(x = c(dim[1]+0.5,dim[1]+0.5), y = c(dim[2]+0.5,0.5), z =  c(dim[3]+0.5,dim[3]+0.5))
-#	lines3d(x = c(dim[1]+0.5,dim[1]+0.5), y = c(dim[2]+0.5,dim[2]+0.5), z =  c(dim[3]+0.5,0.5))
-	wire3d( translate3d( cube3d( trans = scaleMatrix(dim[1]/2,dim[2]/2,dim[3]/2)), (dim[1]+1)/2,(dim[2]+1)/2,(dim[3]+1)/2)) 
-	dot3d( translate3d( cube3d( trans = scaleMatrix(dim[1]/2,dim[2]/2,dim[3]/2)), (dim[1]+1)/2,(dim[2]+1)/2,(dim[3]+1)/2))
-	
-		if(lab){
-	text3d( x = 1:dim[1], y = rep(0, dim[1]), z = rep(0, dim[1]), texts = lvls[[1]])
-	text3d( x = rep(0, dim[2]), y = 1:dim[2], z = rep(0, dim[2]), texts = lvls[[2]])
-	text3d( x = rep(0, dim[3]), y = rep(0, dim[3]), z = 1:dim[3], texts = lvls[[3]])
-	
-	text3d( x = 1:dim[1], y = rep(dim[2]+1, dim[1]), z = rep(dim[3]+1, dim[1]), texts = lvls[[1]])
-	text3d( x = rep(dim[1]+1, dim[2]), y = 1:dim[2], z = rep(dim[3]+1, dim[2]), texts = lvls[[2]])
-	text3d( x = rep(dim[1]+1, dim[3]), y = rep(dim[2]+1, dim[3]), z = 1:dim[3], texts = lvls[[3]])
-		}
-	}
-	apply(x2,1,function(z){
-		s <- ((z[4]/maxfreq)^(1/3))/2
-		  if(shape == "cube"){
-			shade3d( translate3d( cube3d(col=col.array[z[1], z[2], z[3]], trans = scaleMatrix(s,s,s)), z[1], z[2], z[3]), alpha = alpha )	
-		  }
-		  if(shape == "octagon"){
-			 shade3d( translate3d( octahedron3d(col=col.array[z[1], z[2], z[3]], trans = scaleMatrix(s,s,s)), z[1], z[2], z[3]), alpha = alpha )	
-		  }
+	# #MX <- identityMatrix()
+	# MX <- matrix(0,ncol=4,nrow=4)
+	# diag(MX) <- 1
+	# if(!add){
+	# open3d()
 
-	})
+	# wire3d( translate3d( cube3d( trans = scaleMatrix(dim[1]/2,dim[2]/2,dim[3]/2)), (dim[1]+1)/2,(dim[2]+1)/2,(dim[3]+1)/2)) 
+	# dot3d( translate3d( cube3d( trans = scaleMatrix(dim[1]/2,dim[2]/2,dim[3]/2)), (dim[1]+1)/2,(dim[2]+1)/2,(dim[3]+1)/2))
+	
+		# if(lab){
+	# text3d( x = 1:dim[1], y = rep(0, dim[1]), z = rep(0, dim[1]), texts = lvls[[1]])
+	# text3d( x = rep(0, dim[2]), y = 1:dim[2], z = rep(0, dim[2]), texts = lvls[[2]])
+	# text3d( x = rep(0, dim[3]), y = rep(0, dim[3]), z = 1:dim[3], texts = lvls[[3]])
+	
+	# text3d( x = 1:dim[1], y = rep(dim[2]+1, dim[1]), z = rep(dim[3]+1, dim[1]), texts = lvls[[1]])
+	# text3d( x = rep(dim[1]+1, dim[2]), y = 1:dim[2], z = rep(dim[3]+1, dim[2]), texts = lvls[[2]])
+	# text3d( x = rep(dim[1]+1, dim[3]), y = rep(dim[2]+1, dim[3]), z = 1:dim[3], texts = lvls[[3]])
+		# }
+	# }
+	# apply(x2,1,function(z){
+		# s <- ((z[4]/maxfreq)^(1/3))/2
+		  # if(shape == "cube"){
+			# shade3d( translate3d( cube3d(col=col.array[z[1], z[2], z[3]], trans = scaleMatrix(s,s,s)), z[1], z[2], z[3]), alpha = alpha )	
+		  # }
+		  # if(shape == "octagon"){
+			 # shade3d( translate3d( octahedron3d(col=col.array[z[1], z[2], z[3]], trans = scaleMatrix(s,s,s)), z[1], z[2], z[3]), alpha = alpha )	
+		  # }
+
+	# })
 	
 	
-	return(invisible(TRUE))
+	# return(invisible(TRUE))
 	
-}
-cfluctile3d = function(x, xc = NULL, yc = NULL, zc = NULL, shape ="cube", col = c("darkgrey","red"), alpha = c(0.8,0.2),...){
+# }
+
+# cfluctile3d = function(x, xc = NULL, yc = NULL, zc = NULL, shape ="cube", col = c("darkgrey","red"), alpha = c(0.8,0.2),...){
 															
-if(shape %in% c("o","oct","octahedron")){
-	shape <- "octagon"
-}
-	if(is.null(xc)){
-		xc <- attr(x,"xc")
-		if(is.null(xc)){
-			xc <- as.integer(attr(x,"grps")[[1]])
-		}	
-	}
-	if(is.null(yc)){
-		yc <- attr(x,"yc")	
-		if(is.null(yc)){
-			yc <- as.integer(attr(x,"grps")[[2]])
-		}
-	}
-	if(is.null(zc)){
-		zc <- attr(x,"zc")
-		if(is.null(zc)){
-			zc <- as.integer(attr(x,"grps")[[3]])
-		}	
-	}
-	stopifnot( all( c(is.null(xc),is.null(yc),is.null(zc)) == FALSE))
+# if(shape %in% c("o","oct","octahedron")){
+	# shape <- "octagon"
+# }
+	# if(is.null(xc)){
+		# xc <- attr(x,"xc")
+		# if(is.null(xc)){
+			# xc <- as.integer(attr(x,"grps")[[1]])
+		# }	
+	# }
+	# if(is.null(yc)){
+		# yc <- attr(x,"yc")	
+		# if(is.null(yc)){
+			# yc <- as.integer(attr(x,"grps")[[2]])
+		# }
+	# }
+	# if(is.null(zc)){
+		# zc <- attr(x,"zc")
+		# if(is.null(zc)){
+			# zc <- as.integer(attr(x,"grps")[[3]])
+		# }	
+	# }
+	# stopifnot( all( c(is.null(xc),is.null(yc),is.null(zc)) == FALSE))
 	
-	colA <- col[1]
-	colB <- ifelse(length(col) > 1, col[2], "red")
-	alphaA <- alpha[1]
-	alphaB <- ifelse(length(alpha) > 1, alpha[2], 0.2)
+	# colA <- col[1]
+	# colB <- ifelse(length(col) > 1, col[2], "red")
+	# alphaA <- alpha[1]
+	# alphaB <- ifelse(length(alpha) > 1, alpha[2], 0.2)
 	
-	if(!is.data.frame(x)){
-		dim <- dim(x)
-		x <- subtable(as.data.frame(as.table(x)),1:3,allfactor=TRUE)	
+	# if(!is.data.frame(x)){
+		# dim <- dim(x)
+		# x <- subtable(as.data.frame(as.table(x)),1:3,allfactor=TRUE)	
 		
-	}else{
-		dim <- sapply(x,nlevels)[1:3]
-		x <- subtable(x,1:3,allfactor=TRUE)
+	# }else{
+		# dim <- sapply(x,nlevels)[1:3]
+		# x <- subtable(x,1:3,allfactor=TRUE)
 			
-	}
-	ncl <- nlevels(as.factor(xc))
-	xc <- lapply(1:ncl, function(v){
-			which(xc == v)
-		})
-	yc <- lapply(1:ncl, function(v){
-			which(yc == v)
-		})
-	zc <- lapply(1:ncl, function(v){
-			which(zc == v)
-		})
+	# }
+	# ncl <- nlevels(as.factor(xc))
+	# xc <- lapply(1:ncl, function(v){
+			# which(xc == v)
+		# })
+	# yc <- lapply(1:ncl, function(v){
+			# which(yc == v)
+		# })
+	# zc <- lapply(1:ncl, function(v){
+			# which(zc == v)
+		# })
 		
-	stopifnot(length(xc) == length(yc) & length(yc) == length(zc))
-	fluctile3d(x, col = colA, shape = shape, alpha = alphaA)
-	mapply(function(s1,s2,s3){
-		r1 <- diff(range(s1))+1
-		c1 <- mean(range(s1))
-		r2 <- diff(range(s2))+1
-		c2 <- mean(range(s2))
-		r3 <- diff(range(s3))+1
-		c3 <- mean(range(s3))
-		  shade3d( translate3d( cube3d(col=colB, trans = scaleMatrix(r1/1.98,r2/1.98,r3/1.98)), c1, c2, c3), alpha = alphaB )	
+	# stopifnot(length(xc) == length(yc) & length(yc) == length(zc))
+	# fluctile3d(x, col = colA, shape = shape, alpha = alphaA)
+	# mapply(function(s1,s2,s3){
+		# r1 <- diff(range(s1))+1
+		# c1 <- mean(range(s1))
+		# r2 <- diff(range(s2))+1
+		# c2 <- mean(range(s2))
+		# r3 <- diff(range(s3))+1
+		# c3 <- mean(range(s3))
+		  # shade3d( translate3d( cube3d(col=colB, trans = scaleMatrix(r1/1.98,r2/1.98,r3/1.98)), c1, c2, c3), alpha = alphaB )	
 		
-	}, s1 = xc, s2 = yc, s3 = zc)
-		return(invisible(TRUE))
-}
+	# }, s1 = xc, s2 = yc, s3 = zc)
+		# return(invisible(TRUE))
+# }
 
 
-f3dcol = function(x, dims = c(1,2), col.fun = rainbow_hcl, col.opt = list()){
-#require(colorspace)
-	stopifnot( inherits(x, "array") || inherits(x, "table") )
-	nc <- prod(dim(x)[dims])
-	colv <- col.fun(nc)
+# f3dcol = function(x, dims = c(1,2), col.fun = rainbow_hcl, col.opt = list()){
+# #require(colorspace)
+	# stopifnot( inherits(x, "array") || inherits(x, "table") )
+	# nc <- prod(dim(x)[dims])
+	# colv <- col.fun(nc)
 	
-	if(length(dims) == 1){
-		if(dims == 1) colv <- rep(colv, times=prod(dim(x)[2:3]))
-		if(dims == 2) colv <- rep(colv, each = dim(x)[1], times=dim(x)[3])
-		if(dims == 3) colv <- rep(colv, each=prod(dim(x)[1:2]))
-	}
-	if(length(dims) == 2){
-		if(! 1 %in% dims) colv <- rep(colv, each=dim(x)[1])
-		if(! 2 %in% dims){
-			tmp <- NULL
-			for( i in 1:dims[2] ){#1?
-				tmp <- rep(colv[(1:dim(x)[1]) + (i-1)*dim(x)[1]], times = dim(x)[2])
-			}
-			colv <- tmp
-			rm(tmp)
-		} 
-		if(! 3 %in% dims) colv <- rep(colv, times=dim(x)[3])
-	}
-	dim(colv) <- dim(x)
-	return(colv)
-}
+	# if(length(dims) == 1){
+		# if(dims == 1) colv <- rep(colv, times=prod(dim(x)[2:3]))
+		# if(dims == 2) colv <- rep(colv, each = dim(x)[1], times=dim(x)[3])
+		# if(dims == 3) colv <- rep(colv, each=prod(dim(x)[1:2]))
+	# }
+	# if(length(dims) == 2){
+		# if(! 1 %in% dims) colv <- rep(colv, each=dim(x)[1])
+		# if(! 2 %in% dims){
+			# tmp <- NULL
+			# for( i in 1:dims[2] ){#1?
+				# tmp <- rep(colv[(1:dim(x)[1]) + (i-1)*dim(x)[1]], times = dim(x)[2])
+			# }
+			# colv <- tmp
+			# rm(tmp)
+		# } 
+		# if(! 3 %in% dims) colv <- rep(colv, times=dim(x)[3])
+	# }
+	# dim(colv) <- dim(x)
+	# return(colv)
+# }
+
+
+
+# pfluctile <- function(x, freqvar = "Freq", ... ){
+	# if(inherits(x,"table")){
+		# x <- as.data.frame(x)
+	# }
+	# if(!(freqvar %in% names(x))){
+		# freqvar <- NULL
+	# }
+	# nd <- ncol(x) - !is.null(freqvar)
+	# names(x)[names(x) == freqvar] <- "Freq"
+	
+	# #border=c(0.1,0.02,0.02,0.1)
+	
+	# wh <- sapply(x,function(z) nlevels(as.factor(z)))
+	
+	# mat.layout <- grid.layout(nrow = nd , ncol = nd , widths = wh, heights = wh)
+	# grid.newpage()
+	# vp.mat <- viewport(layout = mat.layout)
+	# pushViewport(vp.mat)
+
+	# for(i in 1:(nd-1)){
+		# tt <- xtabs(Freq ~ x[,i]+I(x[,i]),data=x)
+		# fluctile(optile(tt, iter=100),vp=c(i,i), label=c(i==1,i==1),...)
+		# for(j in (i+1):nd){
+		
+			# tt <- xtabs(Freq ~ x[,i]+x[,j],data=x)
+			# fluctile(tt <- optile(tt, iter=100),vp=c(i,j),label=c(j==1,i==1),...)
+			# fluctile(t(tt),vp=c(j,i), label=c(i==1,j==1),...)
+		# }
+	# }
+		# tt <- xtabs(Freq ~ x[,nd]+I(x[,nd]),data=x)
+		# fluctile(optile(tt, iter=100),vp=c(nd,nd), label=FALSE)
+
+# popViewport()
+
+	# return(invisible(TRUE))
+# }
+
+
+
